@@ -24,6 +24,7 @@
 #include <KLocalizedString>
 #include <KConfigGroup>
 #include <KStandardAction>
+#include <KStandardActions>
 #include <KActionCollection>
 #include <KSharedConfig>
 
@@ -36,16 +37,17 @@
 #include <QVBoxLayout>
 #include <QDialogButtonBox>
 #include <QSortFilterProxyModel>
+using namespace Qt::Literals::StringLiterals;
 
 namespace
 {
-const QLatin1String GENERAL_GROUP("General");
+const QLatin1StringView GENERAL_GROUP("General");
 }
 
 BirthdayDlg::BirthdayDlg(QWidget* parent)
     : QDialog(parent)
 {
-    setObjectName(QLatin1StringView("BirthdayDlg"));    // used by LikeBack
+    setObjectName("BirthdayDlg"_L1);    // used by LikeBack
     setWindowTitle(i18nc("@title:window", "Import Birthdays From KAddressBook"));
 
     auto mainLayout = new QVBoxLayout(this);
@@ -230,8 +232,8 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 
 
     KActionCollection* actions = new KActionCollection(this);
-    KStandardAction::selectAll(mListView, &QTreeView::selectAll, actions);
-    KStandardAction::deselect(mListView, &QTreeView::clearSelection, actions);
+    KStandardActions::selectAll(mListView, &QTreeView::selectAll, actions);
+    KStandardActions::deselect(mListView, &QTreeView::clearSelection, actions);
     actions->addAssociatedWidget(mListView);
     const auto lstActions = actions->actions();
     for (QAction* action : lstActions)
