@@ -3,7 +3,7 @@
  *  This file is part of kalarmprivate library, which provides access to KAlarm
  *  calendar data.
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2024 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2025 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -246,27 +246,115 @@ public:
         Audio   = static_cast<int>(KAAlarm::Action::Audio)     //!< play an audio file
     };
 
-    /** What type of occurrence is due. */
-    enum class OccurType
+    /** What type of trigger is due.
+     *  Use the following inline functions to access/set this value:
+     *  - isRecur(TriggerType) to check whether it is a recurrence or only occurrence.
+     *  - recurType(TriggerType) to extract the recurrence type (excluding sub-repetition).
+     *  - isLastRecur(TriggerType) to check whether it is the last recurrence or only occurrence.
+     *  - isFirstRecur(TriggerType) to check whether it is the first recurrence or only occurrence.
+     *  - isOnlyOccur(TriggerType) to check whether it is the only occurrence.
+     *  - isRepeat(TriggerType) to check whether it is a sub-repetition.
+     *  - repeatNum(TriggerType) to extract the sub-repetition number, or 0 if it's a recurrence.
+     *  - setRepeatNum(TriggerType, int) to set the sub-repetition number, or 0 for a recurrence.
+     */
+    enum class TriggerType : unsigned
     {
-        None                = 0,      //!< no occurrence is due
-        FirstOrOnly         = 0x01,   //!< the first occurrence (takes precedence over LastRecur)
-        RecurDate           = 0x02,   //!< a recurrence with only a date, not a time
-        RecurDateTime       = 0x03,   //!< a recurrence with a date and time
-        LastRecur           = 0x04,   //!< the last recurrence
-        Repeat              = 0x10,   //!< (bitmask for a sub-repetition of an occurrence)
-        FirstOrOnlyRepeat   = Repeat | FirstOrOnly,   //!< a sub-repetition of the first occurrence
-        RecurDateRepeat     = Repeat | RecurDate,     //!< a sub-repetition of a date-only recurrence
-        RecurDateTimeRepeat = Repeat | RecurDateTime, //!< a sub-repetition of a date/time recurrence
-        LastRecurRepeat     = Repeat | LastRecur      //!< a sub-repetition of the last recurrence
+        None              = 0,       //!< no occurrence is due
+        Recur             = 0x01,    //!< a recurrence or the only occurrence (bitmask). Use isRecur(TriggerType) to return this.
+        First             = 0x02,    //!< the first occurrence. May be combined with Last.
+        Last              = 0x04,    //!< the last recurrence. May be combined with First.
+        RecurTypeMask     = Recur | First | Last,
+        Reminder          = 0x10,    //!< a reminder for a recurrence
+        Deferral          = 0x20,    //!< a deferral
+        RepeatNumMask     = 0x3FFFC0 //!< the sub-repetition number. Use repeatNum(TriggerType) to extract this.
+                                     //!< Use isRepeat(TriggerType) to check if it's a sub-repetition.
+                                     //!< Use setRepeatNum(TriggerType) to set sub-repetition number into TriggerType.
     };
 
-    /** How to treat sub-repetitions in nextOccurrence(). */
+    static bool isRecur(TriggerType type)
+    { return static_cast<int>(type) & static_cast<int>(TriggerType::Recur); }
+
+    static TriggerType recurType(TriggerType type)
+    { return static_cast<TriggerType>(static_cast<int>(type) & static_cast<int>(TriggerType::RecurTypeMask)); }
+
+    static bool isFirstRecur(TriggerType type)
+    { return static_cast<int>(type) & static_cast<int>(TriggerType::First); }
+
+    static bool isLastRecur(TriggerType type)
+    { return static_cast<int>(type) & static_cast<int>(TriggerType::Last); }
+
+    static bool isOnlyOccur(TriggerType type)
+    { return (static_cast<int>(type) & (static_cast<int>(TriggerType::First) | static_cast<int>(TriggerType::Last))) == (static_cast<int>(TriggerType::First) | static_cast<int>(TriggerType::Last)); }
+
+    static bool isRepeat(TriggerType type)
+    { return static_cast<bool>(static_cast<int>(type) & static_cast<int>(TriggerType::RepeatNumMask)); }
+
+    static int repeatNum(TriggerType type)
+    { return static_cast<int>(static_cast<unsigned>(static_cast<int>(type) & static_cast<unsigned>(TriggerType::RepeatNumMask)) >> 6); }
+
+    static TriggerType setRepeatNum(TriggerType, int repeatNum)
+    { return static_cast<TriggerType>((repeatNum << 6) & static_cast<int>(TriggerType::RepeatNumMask)); }
+
+    /** What type of occurrence is due.
+     *  Use the following inline functions to access/set this value:
+     *  - isRecur(OccurType) to check whether it is a recurrence or only occurrence.
+     *  - recurType(OccurType) to extract the recurrence type (excluding sub-repetition).
+     *  - isLastRecur(OccurType) to check whether it is the last recurrence or only occurrence.
+     *  - isFirstRecur(OccurType) to check whether it is the first recurrence or only occurrence.
+     *  - isOnlyOccur(OccurType) to check whether it is the only occurrence.
+     *  - isRepeat(OccurType) to check whether it is a sub-repetition.
+     *  - repeatNum(OccurType) to extract the sub-repetition number, or 0 if it's a recurrence.
+     *  - setRepeatNum(OccurType, int) to set the sub-repetition number, or 0 for a recurrence.
+     */
+    enum class OccurType : unsigned
+    {
+        None          = (unsigned)TriggerType::None,          //!< no occurrence is due
+        Recur         = (unsigned)TriggerType::Recur,         //!< a recurrence or the only occurrence (bitmask). Use isRecur(OccurType) to return this.
+        First         = (unsigned)TriggerType::First,         //!< the first occurrence. May be combined with Last.
+        Last          = (unsigned)TriggerType::Last,          //!< the last recurrence. May be combined with First.
+        RecurTypeMask = (unsigned)TriggerType::RecurTypeMask,
+        RepeatNumMask = (unsigned)TriggerType::RepeatNumMask  //!< the sub-repetition number. Use repeatNum(OccurType) to extract this.
+                                                       //!< Use isRepeat(OccurType) to check if it's a sub-repetition.
+                                                       //!< Use setRepeatNum(OccurType) to set sub-repetition number into OccurType.
+    };
+
+    static bool isRecur(OccurType type)
+    { return isRecur(static_cast<TriggerType>(type)); }
+
+    static OccurType recurType(OccurType type)
+    { return static_cast<OccurType>(recurType(static_cast<TriggerType>(type))); }
+
+    static bool isFirstRecur(OccurType type)
+    { return isFirstRecur(static_cast<TriggerType>(type)); }
+
+    static bool isLastRecur(OccurType type)
+    { return isLastRecur(static_cast<TriggerType>(type)); }
+
+    static bool isOnlyOccur(OccurType type)
+    { return isOnlyOccur(static_cast<TriggerType>(type)); }
+
+    static bool isRepeat(OccurType type)
+    { return isRepeat(static_cast<TriggerType>(type)); }
+
+    static int repeatNum(OccurType type)
+    { return repeatNum(static_cast<TriggerType>(type)); }
+
+    static OccurType setRepeatNum(OccurType, int repeatNum)
+    { return static_cast<OccurType>(setRepeatNum(TriggerType::None, repeatNum)); }
+
+    /** Whether a sub-repetition is excluded due to working time/holidays. */
+    enum class SubRepExclude
+    {
+        Ok,      //!< not affected by working time/holidays
+        Recur,   //!< the recurrence is excluded due to working time/holidays
+        Repeat   //!< the sub-repetition (but not the recurrence) is excluded due to working time/holidays
+    };
+
+    /** How to treat sub-repetitions in previousOccurrence(). */
     enum class Repeats
     {
         Ignore = 0,    //!< check for recurrences only, ignore sub-repetitions
-        Return,        //!< return a sub-repetition if it's the next occurrence
-        RecurBefore    //!< if a sub-repetition is the next occurrence, return the previous recurrence, not the sub-repetition
+        Return         //!< return a sub-repetition if it's the previous occurrence
     };
 
     /** What type of occurrence currently limits how long the alarm can be deferred. */
@@ -879,8 +967,8 @@ public:
      */
     void setTime(const KADateTime& dt);
 
-    /** Return the next time the event will trigger or be displayed. The evaluation
-     *  depends on @p type:
+    /** Return the next time the event will trigger or be displayed, strictly after the
+     *  specified date/time. The evaluation depends on @p type:
      * - @p type == NextRecur:             returns the next recurrence or only occurrence.
      * - @p type contains NextRepeat:      returns the only occurrence or next
      *                                     recurrence/sub-repetition.
@@ -888,17 +976,20 @@ public:
      *                                     be returned. N.B. Reminders are not displayed for
      *                                     sub-repetitions.
      * - @p type contains NextWorkHoliday: as above but the search continues until a
-     *                                     recurrence is found which occurs during working
-     *                                     hours and not on a holiday.
+     *                                     recurrence is found which complies with any
+     *                                     working hours and holiday restrictions.
      * - @p type contains NextDeferral:    if the event (not a reminder) has been deferred,
      *                                     returns the deferral time.
      *                                     If a reminder has been deferred AND @p type
      *                                     contains NextReminder, returns the deferral time.
      *
-     *  @param type  what to check for when evaluating the next occurrence or display.
+     *  @param preDateTime  the date/time after which to find the next trigger/display.
+     *  @param result       date/time of next trigger/display, or invalid date/time if none.
+     *  @param type         what to check for when evaluating the next trigger/display.
+     *  @param endTime      last date/time to return.
      *  @see startDateTime(), setTime()
      */
-    DateTime nextDateTime(NextTypes type) const;
+    TriggerType nextDateTime(const KADateTime& preDateTime, DateTime& result, NextTypes type, const KADateTime& endTime = {}) const;
 
     /** Return the next time the main alarm will trigger.
      *  @note No account is taken of any working hours or holiday restrictions.
@@ -1009,6 +1100,9 @@ public:
      */
     static void setHolidays(const Holidays& holidays);
 
+    /** Clear the holiday data used by all KAEvent instances. */
+    static void setHolidays();
+
     /** Enable or disable the alarm on non-working days and outside working hours.
      *  Note that this option only has any effect for recurring alarms.
      *  @param wto  true to restrict to working time, false to enable any time
@@ -1036,6 +1130,23 @@ public:
      */
     bool excludedByWorkTimeOrHoliday(const KADateTime& dt) const;
 
+    /** Check whether a sub-repetition conflicts with working hours and/or holiday
+     *  restrictions for the alarm. Note that if its recurrence conflicts, the
+     *  sub-repetition automatically conflicts.
+     *  @note If @p recurDt is date-only, only holidays and/or working days are
+     *        taken account of; working hours are ignored.
+     *  @note No check is made as to whether a recurrence is actually scheduled
+     *        to occur at time @p recurDt.
+     *  @param recurDt  the date/time of the sub-repetition's recurrence.
+     *  @param index    the index to the sub-repetition to check.
+     *  @return whether the alarm is disabled from occurring either because the
+     *               recurrence at @p recurDt is outside working hours (if the alarm
+     *               is working time only) or is during a holiday (if the alarm is
+     *               disabled on holidays), or if the time of the sub-repetition
+     *               is similarly restricted;
+     */
+    SubRepExclude repExcludedByWorkTimeOrHoliday(const KADateTime& recurDt, int index) const;
+
     /** Set working days and times, to be used by all KAEvent instances.
      *  @param days      bits set to 1 for each working day. Array element 0 = Monday ... 6 = Sunday.
      *  @param start     start time in working day.
@@ -1212,7 +1323,7 @@ public:
      *        when determining the next event sub-repetition.
      *
      *  @return sub-repetition count (>=1), or 0 for the main recurrence.
-     *  @see nextOccurrence()
+     *  @see nextDateTime()
      */
     int nextRepetition() const;
 
@@ -1230,7 +1341,7 @@ public:
      *  @param includeRepetitions if true and the alarm has a sub-repetition, the
      *                            method will return true if any sub-repetitions
      *                            occur after @p preDateTime.
-     *  @see nextOccurrence()
+     *  @see nextDateTime()
      */
     bool occursAfter(const KADateTime& preDateTime, bool includeRepetitions) const;
 
@@ -1245,23 +1356,15 @@ public:
      *  @note If the event is date-only, its occurrences are considered to occur
      *        at the start-of-day time when comparing with @p preDateTime.
      *
-     *  @see nextOccurrence()
+     *  @param preDateTime  the date/time after which to set the next occurrence
+     *  @param type         the occurrence type of the next occurrence. Note that
+     *                      only None, Recur and Repeat values/bitmasks are valid;
+     *                      other bit values should be disregarded.
+     *  @return whether the event's next occurrence has been updated
+     *  @see nextDateTime()
      */
-    OccurType setNextOccurrence(const KADateTime& preDateTime);
-
-    /** Get the date/time of the next occurrence of the event, strictly after
-     *  the specified date/time. Reminders are ignored.
-     *  @note No account is taken of any working hours or holiday restrictions
-     *        when determining the next event occurrence.
-     *  @note If the event is date-only, its occurrences are considered to occur
-     *        at the start-of-day time when comparing with @p preDateTime.
-     *
-     *  @param preDateTime the specified date/time.
-     *  @param result      date/time of next occurrence, or invalid date/time if none.
-     *  @param option      how/whether to make allowance for sub-repetitions.
-     *  @see nextRepetition(), setNextOccurrence(), previousOccurrence(), occursAfter()
-     */
-    OccurType nextOccurrence(const KADateTime& preDateTime, DateTime& result, Repeats option = Repeats::Ignore) const;
+    bool setNextOccurrence(const KADateTime& preDateTime, OccurType& type);
+    void setNextOccurrence(const KADateTime& preDateTime);
 
     /** Get the date/time of the last previous occurrence of the event,
      *  strictly before the specified date/time. Reminders are ignored.
@@ -1270,15 +1373,17 @@ public:
      *  @note If the event is date-only, its occurrences are considered to occur
      *        at the start-of-day time when comparing with @p preDateTime.
      *
-     *  @param afterDateTime       the specified date/time.
-     *  @param result              date/time of previous occurrence, or invalid
-     *                             date/time if none.
-     *  @param includeRepetitions  if true and the alarm has a sub-repetition, the
-     *                             last previous repetition is returned if
-     *                             appropriate.
-     *  @see nextOccurrence()
+     *  @param afterDateTime  the specified date/time.
+     *  @param result         date/time of previous occurrence, or invalid
+     *                        date/time if none.
+     *  @param option         = Ignore: only recurrences are returned;
+     *                        = Return: if the alarm has a sub-repetition, the
+     *                                  last previous repetition is returned if
+     *                                  appropriate;
+     *                        Other values must not be specified.
+     *  @see nextDateTime()
      */
-    OccurType previousOccurrence(const KADateTime& afterDateTime, DateTime& result, bool includeRepetitions = false) const;
+    OccurType previousOccurrence(const KADateTime& afterDateTime, DateTime& result, Repeats includeRepetitions) const;
 
     /** Set the event to be a copy of the specified event, making the specified
      *  alarm the 'displaying' alarm.
@@ -1451,6 +1556,15 @@ inline KAEvent::OccurType operator|(KAEvent::OccurType t1, KAEvent::OccurType t2
 inline KAEvent::OccurType operator~(KAEvent::OccurType type)
 { return static_cast<KAEvent::OccurType>(~static_cast<int>(type)); }
 
+inline int operator&(KAEvent::TriggerType t1, KAEvent::TriggerType t2)
+{ return static_cast<int>(t1) & static_cast<int>(t2); }
+
+inline KAEvent::TriggerType operator|(KAEvent::TriggerType t1, KAEvent::TriggerType t2)
+{ return static_cast<KAEvent::TriggerType>(static_cast<int>(t1) | static_cast<int>(t2)); }
+
+inline KAEvent::TriggerType operator~(KAEvent::TriggerType type)
+{ return static_cast<KAEvent::TriggerType>(~static_cast<int>(type)); }
+
 inline int operator&(KAEvent::CmdErr e1, KAEvent::CmdErr e2)
 { return static_cast<int>(e1) & static_cast<int>(e2); }
 
