@@ -15,6 +15,7 @@
 
 #include <QHBoxLayout>
 #include <QLocale>
+using namespace Qt::Literals::StringLiterals;
 
 namespace
 {
@@ -134,7 +135,7 @@ void TimeEdit::slotValueChanged(int value)
 {
     if (mAmPm)
     {
-        bool pm = (mAmPm->currentIndex() == mPmIndex);
+        const bool pm = (mAmPm->currentIndex() == mPmIndex);
         if (pm  &&  value < 720)
             mAmPm->setCurrentIndex(mAmIndex);
         else if (!pm  &&  value >= 720)
@@ -151,11 +152,11 @@ void TimeEdit::slotAmPmChanged(int item)
 {
     if (mAmPm)
     {
-        int value = mSpinBox->value();
-        if (item == mPmIndex  &&  value < 720)
-            mSpinBox->setValue(value + 720);
-        else if (item != mPmIndex  &&  value >= 720)
-            mSpinBox->setValue(value - 720);
+        const int val = mSpinBox->value();
+        if (item == mPmIndex  &&  val < 720)
+            mSpinBox->setValue(val + 720);
+        else if (item != mPmIndex  &&  val >= 720)
+            mSpinBox->setValue(val - 720);
     }
 }
 
@@ -208,7 +209,7 @@ bool use12HourClock()
 {
     const QString fmt = QLocale().timeFormat();
     // 'A' or 'a' = show am/pm; 'H' displays 24-hour format regardless.
-    return fmt.contains(QLatin1Char('a'), Qt::CaseInsensitive) && !fmt.contains(QLatin1Char('H'));
+    return fmt.contains('a'_L1, Qt::CaseInsensitive) && !fmt.contains('H'_L1);
 }
 
 }
